# MiniAn-docker

MiniAn-docker is docker builder for [Minian](https://github.com/DeniseCaiLab/minian). This package provides two type containers. ( `bash` and `notebook` ).

## How to install

1. install and run Docekr

    MiniAn-docker run on a Docker. Please install docker for your OS.

2. install MiniAn-docker: `pip install minian-docker`
3. build and start docker container:
    bash: `minian-docker bash`
    notebook: `minian-docker notebook`

## Contribution to MiniAn-docker

We would love feedback and contribution from the community!

## License

This project is licensed under GNU GPLv3.

## Acknowledgements

```
          ____()()
         /      @@
   `~~~~~\_;m__m._>o
 _____  _____  _____  _____  _____  _____       ____   _____  _____  _____  _____  _____
|     ||     ||   | ||     ||  _  ||   | | ___ |    \ |     ||     ||  |  ||   __|| __  |
| | | ||-   -|| | | ||-   -||     || | | ||___||  |  ||  |  ||   --||    -||   __||    -|
|_|_|_||_____||_|___||_____||__|__||_|___|     |____/ |_____||_____||__|__||_____||__|__|
```

Ascii art in the MOTD is adapted from [https://ascii.co.uk/art/mice](https://ascii.co.uk/art/mice) and [https://patorjk.com/software/taag/#p=display&h=1&f=Rectangles&t=MINIAN-DOCKER](https://patorjk.com/software/taag/#p=display&h=1&f=Rectangles&t=MINIAN-DOCKER).
